@@ -5,7 +5,7 @@ import time
 
 from jinja2 import Markup
 
-from extends import preprocess
+from extensions import preprocess
 
 
 class Funnel(object):
@@ -22,6 +22,11 @@ class Funnel(object):
         app.config.setdefault('CSS_MEDIA_DEFAULT', 'screen,projection,tv')
         app.config.setdefault('BUNDLES_DIR', 'bundles')
         app.config.setdefault('FUNNEL_USE_S3', False)
+        
+        app.config.setdefault('LESS_BIN', 'lessc')
+        app.config.setdefault('SCSS_BIN', 'scss')
+        app.config.setdefault('STYLUS_BIN', 'stylus')
+        app.config.setdefault('COFFEE_BIN', 'coffee')
 
         app.config.setdefault('LESS_PREPROCESS', False)
         app.config.setdefault('SCSS_PREPROCESS', False)
